@@ -1,8 +1,9 @@
 import unittest
 
 import motor.motor_asyncio
+from mongoengine.connection import connect
 from mongoengine.document import Document
-from mongoengine.fields import StringField, IntField
+from mongoengine.fields import IntField, StringField
 
 from asyncmongoengine import connection
 from asyncmongoengine.document import apply_patch
@@ -11,7 +12,7 @@ DBName = "main"
 
 class User(Document):
     meta = {
-        "index": [{"fields": ["sid"], "unique": True}]
+        "indexes": [{"fields": ["sid"], "unique": True}]
     }
     sid = StringField()
     name = StringField()
@@ -20,11 +21,17 @@ class User(Document):
 class TestAsyncDocumentMethod(unittest.IsolatedAsyncioTestCase):
 
     async def asyncSetUp(self):
-        connection.client = motor.motor_asyncio.AsyncIOMotorClient("mongodb")
+        host = "mongodb"
+        port = 27017
+        username = "root"
+        password = "password"
+        connection.client = motor.motor_asyncio.AsyncIOMotorClient(host, port, username=username, password=password)
         await connection.client.drop_database(DBName)
         connection.db = connection.client[DBName]
         apply_patch()
+        connect(host=host, port=port, db=DBName, username=username, password=password)
 
     async def test_unique_index(self):
         User.ensure_indexes()
+        await User(sid="1", name="AA").save_async()
         await User(sid="1", name="AA").save_async()
\ No newline at end of file
